@@ -1,42 +1,3 @@
-#' @importFrom zoo zoo na.locf
-#' @importFrom stats start end
-#' @keywords internal
-fastTickAgregation <- function (ts, on = "minutes", k = 1, tz = "GMT") {
-  
-  if (on == "secs" | on == "seconds") {
-    secs <- k
-    tby <- paste(k, "sec", sep = " ")
-  } 
-  if (on == "mins" | on == "minutes") {
-    secs <- 60 * k
-    tby <- paste(60 * k, "sec", sep = " ")
-  } 
-  if (on == "hours"){
-    secs <- 3600 * k
-    tby <- paste(3600 * k, "sec", sep = " ")
-  } 
-  
-  g <- base::seq(start(ts), end(ts), by = tby)
-  rawg <- as.numeric(as.POSIXct(g, tz = tz))
-  newg <- rawg + (secs - rawg %% secs)
-  g    <- as.POSIXct(newg, origin = "1970-01-01", tz = tz)
-  ts <- na.locf(merge(ts, zoo(NULL, g)))[as.POSIXct(g, tz = tz)]
-  return(ts)
-}
-
-# system.time(aggregateTS(sampleTData$PRICE, k = 5))
-# # 
-# system.time({blub <- sampleTData$PRICE[endpoints(index(sampleTData$PRICE), on = "minutes", k = 5), ]
-# blub <- xts(blub, order.by = ceiling_date(index(blub), unit = paste(5, "minutes")))})
-# blub[1]
-# 
-# 
-# if (index(blub[dim(blub)[1] - 1, ]) == index(blub[dim(blub)[1], ])) {
-#   blub <- blub[-(dim(blub)[1] - 1), ]
-# }
-# 
-# as.xts(index = )
-
 ### Do a daily apply but with list as output:
 #' @importFrom xts try.xts
 #' @importFrom xts endpoints
