@@ -1,5 +1,5 @@
-library(xts)
-
+library("xts")
+library("testthat")
 context("HARmodel")
 test_that("HARModel",{
   expect_equal(
